==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/pt/issues.php <==
<?php
regGS("Issue List", "Lista de Edições");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Nome<br>(Clique para ver Secções)");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publicado<br>(aaaa-mm-dd)");
regGS("Delete issue $1", "Eliminar Número $1");
regGS("Publish articles", "Publicar Artigos");
regGS("Change issue status", "Alterar estado do Número");
regGS("You do not have the right to change issues.", "Não tem permissões para alterar Números");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Tem a certeza que deseja alterar a edição de $1 de $2 para $3?");
regGS("Add new translation", "Adicionar tradução");
regGS("You do not have the right to add issues.", "Não tem permissões para adicionar Números");
regGS("The issue $1 has been successfuly added.", "A Edição $1 foi adicionada com sucesso.");
regGS("The issue could not be added.", "A Edição não pode ser adicionada.");
regGS("Please check if another issue with the same number/language does not already exist.", "P.F: Verifique se já não existe uma Edição/Idioma pretendido");
regGS("Change issue details", "Alterar detalhes da Edição");
regGS("You do not have the right to change issue details.", "Não tem permissões para alterar detalhes de Edições");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Data de Publicação<BR><SMALL>(aaaa-mm-dd)</SMALL>");
regGS("Front Page Template", "Modelo de Página Principal");
regGS("Issue $1 updated in publication $2", "A Edição $1 da Publicação $2 foi alterada");
regGS("You do not have the right to delete issues.", "Não tem permissões para eliminar Edições");
regGS("Are you sure you want to delete the issue $1?", "Tem a certeza que deseja eliminar a Edição $1?");
regGS("Deleting issue", "Eliminando Edição");
regGS("Use the structure of the previous issue", "Usar estrutura da Edição anterior");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Copiar toda a estrutura em todos os Idiomas de Edição anterior, excepto o conteúdo");
regGS("You may modify it later if you wish.", "Poderá modificar mais tarde se o desejar");
regGS("Create a new structure", "Criar uma nova estrutura");
regGS("Create a complete new structure.", "Criar uma Estrutura nova");
regGS("You must define an issue type for each language and then sections for them.", "Tem de definir uma estrutura para cada Idioma.");
regGS("Copy previous issue", "Copiar Edição anterior");
regGS("No previous issue.", "Não existem Edição anterior");
regGS("Copy structure from issue nr $1", "Copiar estrutura da Edição $1");
regGS("Copying previous issue", "Copiar Edição anterior");
regGS("Select the issue", "Escolha a Edição");
regGS("New issue $1 from $2 in publication $3", "Nova Edição $1 de $2 na Publicação $3");
regGS("Adding new issue", "Adicionando nova Edição");
regGS("Delete entry", "Eliminar entrada");
regGS("Issue Publishing Schedule", "Agendar publicação de Edição");
regGS("Invalid Input: $1", "Valor Inválido: $1");
regGS("Issue Number", "Numero de Edição");
regGS("Go To Sections", "Ir para Secções");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Modelo para a Página Principal");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Modelo para Pagina de Artigo");
regGS("Changing issue status", "Alterando o estado no Número");
regGS("Status of the issue $1 has been changed from $2 to $3", "O estado do número $1 foi alterado de $2 para $3");
regGS("Status of the issue $1 could not be changed.", "Estado do Número $1 não pode ser alterado");
regGS("Updating issue", "Actualizando Edição");
regGS("Changing issue's details", "Alterando detalhes da Edição");
regGS("The issue $1 has been successfuly changed.", "A Edição $1 foi alterada com sucesso.");
regGS("The issue could not be changed.", "A Edição não pode ser alterada");
regGS("Preview issue", "Pré-Visualizar Edição");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Esta Edição não pode ser prevista. Verifique se existe um modelo definido.");
regGS("front page", "pagina principal");
regGS("Changing issue template", "Alterando Modelo de Edição");
regGS("You do not have the right to change issue templates.", "Não tem permissões para alterar Modelos de Edição");
regGS("Changing issue template for front page", "Alterando Modelo de Primeira Página para Edição");
regGS("Changing issue template for single article", "Alterando Modelo de Artigo");
regGS("The template has been successfully changed.", "O Modelo foi alterado com sucesso");
regGS("Issue template for publication $1 changed to $2", "Modelo para a Publicação $1 foi alterado para $2");
regGS("Issue template for single articles from $1 changed to $2", "Modelo de Artigo foi alterado de $1 para $2");
regGS("The template could not be changed.", "O Modelo não pode ser alterado");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/pt/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Nome<br>(Clique para ver Secções)");
regGS("Delete issue $1", "Eliminar Número $1");
regGS("Publish articles", "Publicar Artigos");
regGS("You do not have the right to change issues.", "Não tem permissões para alterar Números");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Tem a certeza que deseja alterar a edição de $1 de $2 para $3?");
regGS("Add new translation", "Adicionar tradução");
regGS("You do not have the right to add issues.", "Não tem permissões para adicionar Números");
regGS("The issue $1 has been successfuly added.", "A Edição $1 foi adicionada com sucesso.");
regGS("The issue could not be added.", "A Edição não pode ser adicionada.");
regGS("Change issue details", "Alterar detalhes da Edição");
regGS("You do not have the right to change issue details.", "Não tem permissões para alterar detalhes de Edições");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Data de Publicação<BR><SMALL>(aaaa-mm-dd)</SMALL>");
regGS("Front Page Template", "Modelo de Página Principal");
regGS("Issue $1 updated in publication $2", "A Edição $1 da Publicação $2 foi alterada");
regGS("You do not have the right to delete issues.", "Não tem permissões para eliminar Edições");
regGS("Are you sure you want to delete the issue $1?", "Tem a certeza que deseja eliminar a Edição $1?");
regGS("Use the structure of the previous issue", "Usar estrutura da Edição anterior");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Copiar toda a estrutura em todos os Idiomas de Edição anterior, excepto o conteúdo");
regGS("You may modify it later if you wish.", "Poderá modificar mais tarde se o desejar");
regGS("Create a new structure", "Criar uma nova estrutura");
regGS("Create a complete new structure.", "Criar uma Estrutura nova");
regGS("You must define an issue type for each language and then sections for them.", "Tem de definir uma estrutura para cada Idioma.");
regGS("Copy previous issue", "Copiar Edição anterior");
regGS("No previous issue.", "Não existem Edição anterior");
regGS("Copy structure from issue number $1", "Copiar estrutura da Edição $1");
regGS("New issue $1 from $2 in publication $3", "Nova Edição $1 de $2 na Publicação $3");
regGS("Delete entry", "Eliminar entrada");
regGS("Issue Publishing Schedule", "Agendar publicação de Edição");
regGS("Invalid Input: $1", "Valor Inválido: $1");
regGS("Issue Number", "Numero de Edição");
regGS("Go To Sections", "Ir para Secções");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Modelo para a Página Principal");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Modelo para Pagina de Artigo");
regGS("Changing issue status", "Alterando o estado no Número");
regGS("Status of the issue $1 has been changed from $2 to $3", "O estado do número $1 foi alterado de $2 para $3");
regGS("Status of the issue $1 could not be changed.", "Estado do Número $1 não pode ser alterado");
regGS("Updating issue", "Actualizando Edição");
regGS("Changing issue's details", "Alterando detalhes da Edição");
regGS("The issue $1 has been successfuly changed.", "A Edição $1 foi alterada com sucesso.");
regGS("The issue could not be changed.", "A Edição não pode ser alterada");
regGS("Preview issue", "Pré-Visualizar Edição");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Esta Edição não pode ser prevista. Verifique se existe um modelo definido.");
regGS("front page", "pagina principal");
regGS("Changing issue template", "Alterando Modelo de Edição");
regGS("You do not have the right to change issue templates.", "Não tem permissões para alterar Modelos de Edição");
regGS("Changing issue template for front page", "Alterando Modelo de Primeira Página para Edição");
regGS("Changing issue template for single article", "Alterando Modelo de Artigo");
regGS("The template has been successfully changed.", "O Modelo foi alterado com sucesso");
regGS("Issue template for publication $1 changed to $2", "Modelo para a Publicação $1 foi alterado para $2");
regGS("Issue template for single articles from $1 changed to $2", "Modelo de Artigo foi alterado de $1 para $2");
regGS("The template could not be changed.", "O Modelo não pode ser alterado");
regGS("There was an error reading the language parameter.", "Ocorreu um erro na leitura do parametro de idioma.");
regGS("There was an error reading the publication parameter.", "Ocorreu um erro na leitura do parametro de publicação.");
regGS("There was an error reading the issue parameter.", "Ocorreu um erro na leitura do parametro de secção.");
regGS("There was an error scheduling the $1 action on $2", "Ocorreu um erro no agendamento da tarefa de publicação $1 para $2");
regGS("The action scheduled on $1 could not be deleted.", "A tarefa de publicação agendada para $1 não pode ser eliminada");
?>
